FeSpecularLighting

Struct FeSpecularLighting 

pub struct FeSpecularLighting {
    pub in: Option<Variable<FeIn>>,
    pub surface_scale: Option<Variable<f32>>,
    pub specular_constant: Option<Variable<f32>>,
    pub specular_exponent: Option<Variable<f32>>,
    pub kernel_unit_len: Option<Variable<NumberOptNumber>>,
    pub x: Option<Variable<Length>>,
    pub y: Option<Variable<Length>>,
    pub width: Option<Variable<Length>>,
    pub height: Option<Variable<Length>>,
    pub result: Option<Variable<String>>,
}
This filter primitive lights a source graphic using the alpha channel as a bump map. The resulting image is an RGBA image based on the light color. The lighting calculation follows the standard specular component of the Phong lighting model. The resulting image depends on the light color, light position and surface geometry of the input bump map. The result of the lighting calculation is added. The filter primitive assumes that the viewer is at infinity in the z direction (i.e., the unit vector in the eye direction is (0,0,1) everywhere).

See feSpecularLighting

Fields

in: Option<Variable<FeIn>>surface_scale: Option<Variable<f32>>specular_constant: Option<Variable<f32>>specular_exponent: Option<Variable<f32>>kernel_unit_len: Option<Variable<NumberOptNumber>>x: Option<Variable<Length>>y: Option<Variable<Length>>width: Option<Variable<Length>>height: Option<Variable<Length>>result: Option<Variable<String>>