pub struct FeSpecularLighting {
pub in: Option<Variable<FeIn>>,
pub surface_scale: Option<Variable<f32>>,
pub specular_constant: Option<Variable<f32>>,
pub specular_exponent: Option<Variable<f32>>,
pub kernel_unit_len: Option<Variable<NumberOptNumber>>,
pub x: Option<Variable<Length>>,
pub y: Option<Variable<Length>>,
pub width: Option<Variable<Length>>,
pub height: Option<Variable<Length>>,
pub result: Option<Variable<String>>,
}Expand description
This filter primitive lights a source graphic using the alpha channel as a bump map. The resulting image is an RGBA image based on the light color. The lighting calculation follows the standard specular component of the Phong lighting model. The resulting image depends on the light color, light position and surface geometry of the input bump map. The result of the lighting calculation is added. The filter primitive assumes that the viewer is at infinity in the z direction (i.e., the unit vector in the eye direction is (0,0,1) everywhere).
Fields
in: Option<Variable<FeIn>>surface_scale: Option<Variable<f32>>specular_constant: Option<Variable<f32>>specular_exponent: Option<Variable<f32>>kernel_unit_len: Option<Variable<NumberOptNumber>>x: Option<Variable<Length>>y: Option<Variable<Length>>width: Option<Variable<Length>>height: Option<Variable<Length>>result: Option<Variable<String>>Trait Implementations
Sourceimpl Clone for FeSpecularLighting
impl Clone for FeSpecularLighting
Sourcefn clone(&self) -> FeSpecularLighting
fn clone(&self) -> FeSpecularLighting
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FeSpecularLighting
impl Debug for FeSpecularLighting
Sourceimpl<'de> Deserialize<'de> for FeSpecularLighting
impl<'de> Deserialize<'de> for FeSpecularLighting
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Deserialize for FeSpecularLighting
impl Deserialize for FeSpecularLighting
type Value = FeSpecularLighting
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer,
Derserialize this value from given
derserializer.Sourceimpl From<FeSpecularLighting> for Element
impl From<FeSpecularLighting> for Element
Sourcefn from(value: FeSpecularLighting) -> Self
fn from(value: FeSpecularLighting) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for FeSpecularLighting
impl PartialEq for FeSpecularLighting
Sourceimpl PartialOrd for FeSpecularLighting
impl PartialOrd for FeSpecularLighting
Sourceimpl Serialize for FeSpecularLighting
impl Serialize for FeSpecularLighting
Sourceimpl Serialize for FeSpecularLighting
impl Serialize for FeSpecularLighting
impl StructuralPartialEq for FeSpecularLighting